2022-08-24 Version: 1.0.14
- AMP version.

2022-07-28 Version: 1.0.13
 - Delete SetDcdnConfigOfVersion.

2022-07-05 Version: 1.0.12
 - Add DescribeDcdnIpaDomainMultiUsageData.

2022-06-09 Version: 1.0.11
 - Update DescribeDcdnSLSRealtimeLogDelivery.

2022-05-26 Version: 1.0.10
 - Add SetDcdnFullDomainsBlockIP.

2022-04-28 Version: 1.0.9
- Add DescribeDcdnWafDomains.

2022-04-07 Version: 1.0.8
- Add DescribeDcdnWafService.

2022-03-31 Version: 1.0.7
- Add waf api.

2022-03-31 Version: 1.0.6
- AMP version.

2022-03-28 Version: 1.0.5
- AMP version.

2022-03-22 Version: 1.0.4
- Update PreloadDcdnObjectCaches.

2022-01-06 Version: 1.0.3
- Update ErrorCode.

2021-12-31 Version: 1.0.2
- Update ErrorCode.

2021-12-29 Version: 1.0.1
- AMP version.

2021-06-08 Version: 1.0.0
- Generated python2 2018-01-15 for dcdn.

